@@ -15,6 +15,11 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with the Pygame SGE.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import division
+from __future__ import absolute_import
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import pygame
 
 import sge
@@ -23,7 +28,7 @@ import sge
 __all__ = ['Room']
 
 
-class Room:
+class Room(object):
 
     """Class for rooms.
 
@@ -713,10 +718,7 @@ class Room:
         for more information.
 
         """
-        if sge.DEBUG:
-            bad_name = "event_loose_keyboard_focus"
-            if hasattr(self, bad_name):
-                sge._scold_user_on_lose_vs_loose(bad_name)
+        pass
 
     def event_gain_mouse_focus(self):
         """Gain mouse focus event.
@@ -734,10 +736,7 @@ class Room:
         more information.
 
         """
-        if sge.DEBUG:
-            bad_name = "event_loose_mouse_focus"
-            if hasattr(self, bad_name):
-                sge._scold_user_on_lose_vs_loose(bad_name)
+        pass
 
     def event_close(self):
         """Close event.
@@ -857,10 +856,7 @@ class Room:
         for more information.
 
         """
-        if sge.DEBUG:
-            bad_name = "event_paused_loose_keyboard_focus"
-            if hasattr(self, bad_name):
-                sge._scold_user_on_lose_vs_loose(bad_name)
+        pass
 
     def event_paused_gain_mouse_focus(self):
         """Gain mouse focus event when paused.
@@ -878,10 +874,7 @@ class Room:
         more information.
 
         """
-        if sge.DEBUG:
-            bad_name = "event_paused_loose_mouse_focus"
-            if hasattr(self, bad_name):
-                sge._scold_user_on_lose_vs_loose(bad_name)
+        pass
 
     def event_paused_close(self):
         """Close event when paused.
