@@ -1,20 +1,25 @@
 # Copyright (C) 2012, 2013, 2014 Julian Marchant <onpon4@riseup.net>
-# 
+#
 # This file is part of the Pygame SGE.
-# 
+#
 # The Pygame SGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # The Pygame SGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU Lesser General Public License
 # along with the Pygame SGE.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import division
+from __future__ import absolute_import
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import os
 import warnings
 
@@ -26,7 +31,7 @@ import sge
 __all__ = ['Sprite']
 
 
-class Sprite:
+class Sprite(object):
 
     """Class which holds information for images and animations.
 
@@ -128,7 +133,7 @@ class Sprite:
 
     @property
     def width(self):
-        return self._w
+        return int(round(self._w))
 
     @width.setter
     def width(self, value):
@@ -139,7 +144,7 @@ class Sprite:
 
     @property
     def height(self):
-        return self._h
+        return int(round(self._h))
 
     @height.setter
     def height(self, value):
@@ -236,9 +241,6 @@ class Sprite:
         information.
 
         """
-        if sge.DEBUG:
-            print('Creating sprite "{}"'.format(name))
-
         sprites = sge.game.sprites.copy()
 
         self.name = name
@@ -267,7 +269,8 @@ class Sprite:
                     fnames = os.listdir(path)
                     for fname in fnames:
                         full_fname = os.path.join(path, fname)
-                        if fname.startswith(name) and os.path.isfile(full_fname):
+                        if (fname.startswith(name) and
+                                os.path.isfile(full_fname)):
                             root, ext = os.path.splitext(fname)
                             if root == name:
                                 split = [name, '']
@@ -294,8 +297,7 @@ class Sprite:
                 try:
                     img = pygame.image.load(fname_single)
                 except pygame.error:
-                    if sge.DEBUG:
-                        print("Ignored {}; not a valid image.".format(fname_single))
+                    pass
                 else:
                     self._baseimages.append(img)
 
@@ -306,8 +308,7 @@ class Sprite:
                         try:
                             img = pygame.image.load(fname)
                         except pygame.error:
-                            if sge.DEBUG:
-                                print("Ignored {}; not a valid image.".format(fname))
+                            pass
                         else:
                             self._baseimages.append(img)
 
@@ -325,8 +326,7 @@ class Sprite:
                 try:
                     sheet = pygame.image.load(fname_strip)
                 except pygame.error:
-                    if sge.DEBUG:
-                        print("Ignored {}; not a valid image.".format(fname_strip))
+                    pass
                 else:
                     assert split[1][5:].isdigit()
                     n = int(split[1][5:])
@@ -364,8 +364,6 @@ class Sprite:
                     self.id += 1
 
             self.append_frame()
-            if sge.DEBUG:
-                print("renamed to {}, ID is {}".format(self.name, self.id))
 
         if width is None:
             width = 1
@@ -444,6 +442,8 @@ class Sprite:
           frames.
 
         """
+        x = int(round(x))
+        y = int(round(y))
         color = sge._get_pygame_color(color)
         if color.a == 255:
             for i in range(self.frames):
@@ -480,6 +480,11 @@ class Sprite:
           frames.
 
         """
+        x1 = int(round(x1))
+        y1 = int(round(y1))
+        x2 = int(round(x2))
+        y2 = int(round(y2))
+        thickness = int(round(thickness))
         color = sge._get_pygame_color(color)
         thickness = abs(thickness)
 
@@ -527,6 +532,10 @@ class Sprite:
           frames.
 
         """
+        x = int(round(x))
+        y = int(round(y))
+        width = int(round(width))
+        height = int(round(height))
         outline_thickness = abs(outline_thickness)
         if outline_thickness == 0:
             outline = None
@@ -587,6 +596,10 @@ class Sprite:
           frames.
 
         """
+        x = int(round(x))
+        y = int(round(y))
+        width = int(round(width))
+        height = int(round(height))
         outline_thickness = abs(outline_thickness)
         if outline_thickness == 0:
             outline = None
@@ -646,6 +659,9 @@ class Sprite:
           frames.
 
         """
+        x = int(round(x))
+        y = int(round(y))
+        radius = int(round(radius))
         outline_thickness = abs(outline_thickness)
         if outline_thickness == 0:
             outline = None
@@ -720,11 +736,13 @@ class Sprite:
           :const:`None` is treated as :data:`sge.BLEND_NORMAL`.
 
         """
+        x = int(round(x))
+        y = int(round(y))
         if not isinstance(sprite, sge.Sprite):
             sprite = sge.game.sprites[sprite]
 
-        x -= sprite.origin_x
-        y -= sprite.origin_y
+        x -= int(round(sprite.origin_x))
+        y -= int(round(sprite.origin_y))
         image %= len(sprite._baseimages)
 
         if blend_mode is not None and blend_mode & sge.BLEND_SCREEN:
@@ -816,6 +834,8 @@ class Sprite:
         """
         if not isinstance(font, sge.Font):
             font = sge.game.fonts[font]
+        x = int(round(x))
+        y = int(round(y))
 
         lines = font._split_text(text, width)
         width = font.get_width(text, width, height)
@@ -1134,7 +1154,7 @@ class Sprite:
             for image in self._baseimages:
                 img = self._set_transparency(image)
                 img = sge._scale(img, self.width, self.height)
-                self._images.append({(1, 1, 0, 255, None):img})
+                self._images.append({(1, 1, 0, 255, None): img})
 
     def _set_transparency(self, image):
         # Return a copy of the surface with transparency properly set
