@@ -1,17 +1,17 @@
 # Copyright (C) 2012, 2013, 2014 Julian Marchant <onpon4@riseup.net>
-# 
+#
 # This file is part of the Pygame SGE.
-# 
+#
 # The Pygame SGE is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # The Pygame SGE is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Lesser General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU Lesser General Public License
 # along with the Pygame SGE.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -435,7 +435,12 @@ by default.
 
 """
 
-__version__ = "0.10.0"
+from __future__ import division
+from __future__ import absolute_import
+from __future__ import print_function
+from __future__ import unicode_literals
+
+__version__ = "0.10.1"
 
 import sys
 import os
@@ -446,7 +451,6 @@ import pygame
 PROGRAM_DIR = os.path.dirname(sys.argv[0])
 IMPLEMENTATION = "Pygame SGE"
 COLLISION_AREA_SIZE_DEFAULT = 128
-DEBUG = False
 
 ALIGN_LEFT = 2
 ALIGN_CENTER = 3
@@ -655,20 +659,3 @@ def _get_pygame_color(color):
                 return pygame.Color(color)
         except ValueError:
             return pygame.Color(0, 0, 0, 0)
-
-
-def _scold_user_on_lose_vs_loose(attempted_name):
-    # Tell the user that they misspelled "lose" as "loose".
-    m = '\n'.join((
-        'Huh? I don\'t have a method called "{}".'.format(attempted_name),
-        'You do know that "lose" (a verb meaning "to fail to keep or hold")',
-        'is not spelled the same as "loose" (an adjective meaning "not',
-        'tightly fastened, attached, or held"), right?'))
-
-    print(m)
-    m = m.replace('\n', ' ')
-    show_message(m)
-
-
-if DEBUG:
-    print("SGE Art of Debugging enabled.")
